Index: trunk/ippScripts/scripts/ipp_serial_detrend.pl
===================================================================
--- trunk/ippScripts/scripts/ipp_serial_detrend.pl	(revision 17163)
+++ trunk/ippScripts/scripts/ipp_serial_detrend.pl	(revision 17172)
@@ -13,9 +13,11 @@
 
 my ($dbname,			# Database name to use
-    $workdir_global		# Global working directory
+    $workdir_global,		# Global working directory
+    $verbose,			# Produce verbose output?
     );
 GetOptions(
 	   'dbname=s'  => \$dbname,
 	   'workdir=s' => \$workdir_global,
+	   'verbose'   => \$verbose,
 ) or pod2usage( 2 );
 
@@ -80,4 +82,5 @@
 		my $command = "$detrend_process_imfile --det_id $det_id --exp_tag $exp_tag --exp_id $exp_id --class_id $class_id --det_type $det_type --input_uri $uri --camera $camera --dbname $dbname --outroot $outroot";
 		$command .= " --reduction $reduction" if defined $reduction;
+		$command .= " --verbose" if defined $verbose;
 		my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 		    run( command => $command, verbose => 1 );
@@ -115,4 +118,5 @@
 
 	my $command = "$detrend_process_exp --det_id $det_id --det_type $det_type --exp_tag $exp_tag --exp_id $exp_id --camera $camera --dbname $dbname --outroot $outroot";
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
@@ -148,4 +152,5 @@
 	my $command = "$detrend_stack --det_id $det_id --iteration $iteration --class_id $class_id --det_type $det_type --camera $camera --dbname $dbname --outroot $outroot";
 	$command .= " --reduction $reduction" if defined $reduction;
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
@@ -177,4 +182,5 @@
 
 	my $command = "$detrend_norm_calc --det_id $det_id --iteration $iteration --det_type $det_type --dbname $dbname --outroot $outroot";
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
@@ -209,4 +215,5 @@
 
 	my $command = "$detrend_norm_apply --det_id $det_id --iteration $iteration --class_id $class_id --value $value --input_uri $uri --camera $camera --det_type $det_type --dbname $dbname --outroot $outroot";
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
@@ -241,4 +248,5 @@
 
 	my $command = "$detrend_norm_exp --det_id $det_id --iteration $iteration --camera $camera --det_type $det_type --dbname $dbname --outroot $outroot";
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
@@ -289,4 +297,5 @@
 		$command .= " --reduction $reduction" if defined $reduction;
 		$command .= " --detrend $detrend" if defined $detrend;
+		$command .= " --verbose" if defined $verbose;
 
 		my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
@@ -326,4 +335,5 @@
 
 	my $command = "$detrend_reject_imfile --det_id $det_id --iteration $iteration --exp_tag $exp_tag --exp_id $exp_id --det_type $det_type --camera $camera --dbname $dbname --outroot $outroot";
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
@@ -355,4 +365,5 @@
 
 	my $command = "$detrend_reject_exp --det_id $det_id --iteration $iteration --det_type $det_type --camera $camera --dbname $dbname --outroot $outroot";
+	$command .= " --verbose" if defined $verbose;
     	my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
 	    run( command => $command, verbose => 1 );
